@@ -32,9 +32,9 @@ volatile int running;
 struct statistics *packets;
 
 #ifndef HASH_SIZE
-#define HASH_SIZE 256
+#define HASH_SIZE 4096
 #endif
-#define HASH(s,d) ((s &0xff)^(s &0xff))
+#define HASH(s,d) ((s &0xfff)^(d &0xfff))
 
 
 static struct ipdata *plist[HASH_SIZE]; /* data being collected */
@@ -61,7 +61,6 @@ void remap_masq(struct ipdata *p)
 {
     FILE *fd;
     char buf[257];
-    int line=0;
     char *protocol;
     char searchtext[20];
     int plen;
@@ -70,22 +69,23 @@ void remap_masq(struct ipdata *p)
 	protocol = "TCP";
     else if(p->proto == 17) 
 	protocol = "UDP";
-    else /* what about ICMP masquerading?? */
+    else if(p->proto == 1)
+	protocol = "ICMP";
+    else
 	return;
 
     plen = strlen(protocol);
     sprintf(searchtext, "%08lX:%04X %04X",ntohl(p->dst), 
-	p->dstport, p_.srcport);
+	p->dstport, p->srcport);
     if((fd=fopen(PROC_MASQ_FILENAME,"r")) == NULL)
 	return;
 
     while(fgets(buf,257,fd)) {
-	if(line++ &&
-	  (strncmp(protocol, buf, plen) == 0) &&
+	  if((strncmp(protocol,buf,plen) == 0) &&
 	  (strncmp(searchtext, buf+plen+15, 18) == 0)) {
 	    p->msqsrc = htonl(strtoul(buf+plen+1, NULL, 16));
 	    p->msqport = strtoul(buf+plen+10, NULL, 16);
-	    fclose(fd);
+	    break;
 	}
     }
     fclose(fd);
@@ -788,6 +788,7 @@ void signal_debug(int sig)
       struct headerdat *h,*h_next;
       struct mon_host_struct *mh,*mh_next;
       DEBUG(DBG_STATE, sprintf(dbg, "received SIGHUP, rereading config\n"));
+      exit_capture();
       if(cfg) {
 	free(cfg->filename);
 	free(cfg->dumpname);
@@ -827,6 +828,7 @@ void signal_debug(int sig)
 	free(cfg);
       }
       cfg = read_config(fname);
+      init_capture();
   }
   else
     {
